@@ -74,7 +74,7 @@ class CogniacApplication(object):
         if app_managers is not None:
             data['app_managers'] = app_managers
 
-        resp = connection._post("/applications", json=data)
+        resp = connection._post("/1/applications", json=data)
 
         return CogniacApplication(connection, resp.json())
 
@@ -92,7 +92,7 @@ class CogniacApplication(object):
         connnection (CogniacConnection):     Authenticated CogniacConnection object
         application_id (String):             The application_id of the Cogniac application to return
         """
-        resp = connection._get("/applications/%s" % application_id)
+        resp = connection._get("/1/applications/%s" % application_id)
         return CogniacApplication(connection, resp.json())
 
     ##
@@ -105,7 +105,7 @@ class CogniacApplication(object):
 
         connnection (CogniacConnection):     Authenticated CogniacConnection object
         """
-        resp = connection._get('/tenants/%s/applications' % connection.tenant.tenant_id)
+        resp = connection._get('/1/tenants/%s/applications' % connection.tenant.tenant_id)
         apps = resp.json()['data']
         return [CogniacApplication(connection, appd) for appd in apps]
 
@@ -142,7 +142,7 @@ class CogniacApplication(object):
         Delete the application.
         This will delete existing models but will not delete associated subjects or media.
         """
-        self._cc._delete("/applications/%s" % self.application_id)
+        self._cc._delete("/1/applications/%s" % self.application_id)
 
         for k in self._app_keys:
             delattr(self, k)
@@ -151,7 +151,7 @@ class CogniacApplication(object):
         self.connection = None
 
     def __post_update__(self, data):
-        resp = self._cc._post("/applications/%s" % self.application_id, json=data)
+        resp = self._cc._post("/1/applications/%s" % self.application_id, json=data)
         self.__parse_app_dict__(resp.json())
 
     def __setattr__(self, name, value):
@@ -164,7 +164,7 @@ class CogniacApplication(object):
         if name in ['name', 'description', 'active', 'input_subjects', 'output_subjects', 'app_managers',
                     'detection_post_urls', 'detection_thresholds', 'custom_fields', 'app_type_config',
                     'edgeflow_upload_policies', 'override_upstream_detection_filter', 'feedback_resample_ratio',
-                    'reviewers']:
+                    'reviewers', 'inference_execution_policies', 'primary_release_metric', 'secondary_evaluation_metrics']:
             data = {name: value}
             self.__post_update__(data)
             return
@@ -202,7 +202,7 @@ class CogniacApplication(object):
         Return the integer number of feedback requests pending for this application.
         This is useful for controlling the flow of images input into the system to avoid creating too many backlogged feedback requests.
         """
-        resp = self._cc._get("/applications/%s/feedback/pending" % self.application_id)
+        resp = self._cc._get("/1/applications/%s/feedback/pending" % self.application_id)
         return resp.json()['pending']
 
     ##
@@ -215,7 +215,7 @@ class CogniacApplication(object):
 
         limit (Int):   Maximum number of feedback request messages to return
         """
-        resp = self._cc._get("/applications/%s/feedback?limit=%d" % (self.application_id, limit))
+        resp = self._cc._get("/1/applications/%s/feedback?limit=%d" % (self.application_id, limit))
         return resp.json()
 
     ##
@@ -230,7 +230,7 @@ class CogniacApplication(object):
         subjects (list of dicts):      Subject-media association dictionaries of the form:
 
             subject_uid:               Subject UID
-            result (str):              Either 'True', 'False', 'Uncertain'
+            result (str):              One of 'True', 'False', 'Sidelined'
             app_data_type (String):    (Optional) Type of extra app-specific data for certain app types
             app_data (Object):         (Optional) Additional, app-specific, subject-media association data
 
@@ -243,7 +243,7 @@ class CogniacApplication(object):
         feedback_response = {'media_id': media_id,
                              'subjects': subjects}
 
-        self._cc._post("/applications/%s/feedback" % self.application_id, json=feedback_response)
+        self._cc._post("/1/applications/%s/feedback" % self.application_id, json=feedback_response)
 
     ##
     #  list of models released
@@ -267,7 +267,7 @@ class CogniacApplication(object):
             assert(limit > 0)
             args.append('limit=%d' % min(limit, 100))  # api support max limit of 100
 
-        url = "/applications/%s/models?" % self.application_id
+        url = "/1/applications/%s/models?" % self.application_id
         url += "&".join(args)
 
         @retry(stop_max_attempt_number=8, wait_exponential_multiplier=500, retry_on_exception=server_error)
@@ -299,7 +299,7 @@ class CogniacApplication(object):
         """
         return the modelname for the current best model for this application
         """
-        resp = self._cc._get("/applications/%s/ccp" % self.application_id)
+        resp = self._cc._get("/1/applications/%s/ccp" % self.application_id)
         resp = resp.json()
 
         url = resp['best_model_ccp_url']
@@ -316,14 +316,14 @@ class CogniacApplication(object):
         return the local filename which will be the same as the model name.
         """
         if model_id is None:
-            resp = self._cc._get("/applications/%s/ccp" % self.application_id)
+            resp = self._cc._get("/1/applications/%s/ccp" % self.application_id)
             resp = resp.json()
             url = resp['best_model_ccp_url']
             modelname = url.split('/')[-1]
         else:
             modelname = model_id.split('/')[-1]
 
-        resp = self._cc._get("/applications/%s/ccppkg" % self.application_id, json={"ccp_filename": modelname})
+        resp = self._cc._get("/1/applications/%s/ccppkg" % self.application_id, json={"ccp_filename": modelname})
 
         fp = open(modelname, "wb")
         fp.write(resp.content)
@@ -395,7 +395,7 @@ class CogniacApplication(object):
         if abridged_media:
             args.append('abridged_media=True')
 
-        url = "/applications/%s/detections?" % self.application_id
+        url = "/1/applications/%s/detections?" % self.application_id
         url += "&".join(args)
 
         @retry(stop_max_attempt_number=8, wait_exponential_multiplier=500, retry_on_exception=server_error)
@@ -417,7 +417,7 @@ class CogniacApplication(object):
         """
         return single cummulative app usage record for start to end epoch times
         """
-        url = "/usage/app/%s?start=%d&end=%d&accumulate=True" % (self.application_id, start, end)
+        url = "/1/usage/app/%s?start=%d&end=%d&accumulate=True" % (self.application_id, start, end)
         resp = self._cc._get(url)
         data = resp.json()['data']
         return data[0] if len(data) else None
@@ -426,7 +426,7 @@ class CogniacApplication(object):
         """
         yield sparse app usage records in order between start and end epoch times
         """
-        url = "/usage/app/%s?start=%d&end=%d" % (self.application_id, start, end)
+        url = "/1/usage/app/%s?start=%d&end=%d" % (self.application_id, start, end)
 
         @retry(stop_max_attempt_number=8, wait_exponential_multiplier=5, retry_on_exception=server_error)
         def get_next(url):
@@ -451,7 +451,7 @@ class CogniacApplication(object):
         def __get_app_type_config_dict__(self):
             d = {}
 
-            for k, v in self.__dict__.iteritems():
+            for k, v in self.__dict__.items():
                 if k in self._app_type_config_keys:
                     d[k] = v
 
