@@ -5,22 +5,24 @@ Copyright (C) 2016 Cogniac Corporation
 """
 
 import os
-import six
-import sys
-import requests
 import re
+from time import time
+import six
+import requests
 from retrying import retry
 from requests.packages.urllib3 import Retry
 from requests.adapters import HTTPAdapter
-from time import time
 
 from .common import server_error, raise_errors
-
 from .media import file_creation_time
 
+
 IP_REGEX = re.compile('^(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])$')
 
 
+CLOUDFLOW_PREFIX = "cloudflow.cogniac.io"
+
+
 @six.python_2_unicode_compatible
 class CogniacEdgeFlow(object):
     """
@@ -37,12 +39,12 @@ class CogniacEdgeFlow(object):
                                          Defaults to `None`. If unspecified, the EdgeFlow's local APIs will not be available
 
     Connect to a Cogniac EdgeFlow and maintain session state.
-    
+
     Class definition for an object that stores information about a physical
     Cogniac EdgeFlow and methods that provide a client
     interface for programmatically managing and requesting work to be done
     on the EdgeFlow.
-    
+
     A Cogniac EdgeFlow object's methods can be used to trigger media capture
     (e.g., triggering cameras to save images to an EdgeFlow) and ingesting
     media from another host on the same network.
@@ -58,7 +60,7 @@ class CogniacEdgeFlow(object):
         returns CogniacEdgeFlow object
         """
         edgeflow_dict = None
-        resp = connection._get("/gateways/{}".format(edgeflow_id))
+        resp = connection._get("/1/gateways/{}".format(edgeflow_id))
         return CogniacEdgeFlow(connection, resp.json())
 
     @classmethod
@@ -68,7 +70,7 @@ class CogniacEdgeFlow(object):
 
         connnection (CogniacConnection):     Authenticated CogniacConnection object
         """
-        resp = connection._get('/tenants/%s/gateways' % connection.tenant.tenant_id)
+        resp = connection._get('/1/tenants/%s/gateways' % connection.tenant.tenant_id)
         edgeflows = resp.json()['data']
         return [CogniacEdgeFlow(connection, edgeflow) for edgeflow in edgeflows]
 
@@ -85,14 +87,6 @@ class CogniacEdgeFlow(object):
         for k, v in edgeflow_dict.items():
             super(CogniacEdgeFlow, self).__setattr__(k, v)
 
-        # Validate IP address.
-        self.url_prefix = None
-        try:
-            if self.ip_address and IP_REGEX.match(self.ip_address):
-                self.url_prefix = 'http://{}:8000/1'.format(self.ip_address)
-        except:
-            pass
-
         self.timeout = timeout
 
         self.__initialize()
@@ -102,7 +96,7 @@ class CogniacEdgeFlow(object):
             super(CogniacEdgeFlow, self).__setattr__(name, value)
             return
         data = {name: value}
-        resp = self._cc._post("/gateways/%s" % self.gateway_id, json=data)
+        resp = self._cc._post("/1/gateways/%s" % self.gateway_id, json=data)
         for k, v in resp.json().items():
             super(CogniacEdgeFlow, self).__setattr__(k, v)
 
@@ -117,11 +111,29 @@ class CogniacEdgeFlow(object):
     #  EdgeFlow API.
     #
     # -------------------------------------------------------------------------
+    def __set_url_prefix(self):
+        """ Setup url prefix based on model of Edgeflow (cloudflow vs edgeflow).
+            For local http actions, the WAN0 ip address is used"""
+        self.url_prefix = None
+        if 'cf' in self.model.lower():
+            # cloudflow uses https based post request with token
+            self.url_prefix = 'https://{}.{}'.format(self.gateway_id, CLOUDFLOW_PREFIX)
+            self._post = self._cc._post
+        else:
+            # use wan0 if available as the http destination ip addres
+            ifconfigs = list(self.status(subsystem_name='ifconfig', limit=1))
+
+            if ifconfigs:
+                self.ip_address = ifconfigs[0]['status']['wan0']['ip']
+
+                if IP_REGEX.match(self.ip_address):
+                    self.url_prefix = 'http://{}:8000'.format(self.ip_address)
 
-    @retry(stop_max_attempt_number=8, wait_exponential_multiplier=500, retry_on_exception=server_error)
     def __initialize(self):
         self.session = requests.Session()
 
+        self.__set_url_prefix()
+
         # Configure session with appropriate retries.
         self.session.mount('https://', HTTPAdapter(
             max_retries=Retry(connect=5,
@@ -160,9 +172,10 @@ class CogniacEdgeFlow(object):
         return resp
 
     def get_version(self):
-        resp = self._get("/version")
+        resp = self._get("/1/version")
         return resp.json()
 
+
     def process_media(self,
                       subject_uid,
                       filename,
@@ -173,7 +186,7 @@ class CogniacEdgeFlow(object):
         """
         Uploads a media file object to an EdgeFlow device.
 
-        subject_uid		                  A subject's unique identifier.
+        subject_uid                               A subject's unique identifier.
         filename (str):                   Local filename or http/s URL of image or video media file
         external_media_id (str):          Optional arbitrary external id for this media
         media_timestamp (float):          Optional actual timestamp of media creation/occurance time
@@ -210,7 +223,8 @@ class CogniacEdgeFlow(object):
                 raise Exception("The media file must be uploaded from local storage.")
             else:
                 files = {'file': open(filename, 'rb')}
-            resp = self._post("/process/{}".format(subject_uid), data=args, files=files)
+            url = "%s/%s/%s" % (self.url_prefix, "1/process", subject_uid)
+            resp = self._post(url, data=args, files=files)
             return resp
 
         resp = upload()
@@ -230,7 +244,7 @@ class CogniacEdgeFlow(object):
         args = dict()
         args['start_time'] = start_time
         args['end_time'] = end_time
-        self._cc._post("/gateways/%s/event/time_bound_media_upload" % (self.gateway_id), json=args)
+        self._cc._post("/1/gateways/%s/event/time_bound_media_upload" % (self.gateway_id), json=args)
 
 
     def flush_upload_queue(self, start_time=None, end_time=None):
@@ -242,7 +256,7 @@ class CogniacEdgeFlow(object):
             args['start_time'] = start_time
         if end_time is not None:
             args['end_time'] = end_time
-        self._cc._post("/gateways/%s/event/flush_upload_queue" % (self.gateway_id), json=args)
+        self._cc._post("/1/gateways/%s/event/flush_upload_queue" % (self.gateway_id), json=args)
 
 
     def factory_reset(self):
@@ -250,7 +264,7 @@ class CogniacEdgeFlow(object):
         Factory reset the EdgeFlow.
         This results in deletion of this EdgeFlow object in CloudCore/SiteCore!
         """
-        self._cc._post("/gateways/%s/event/factory_reset" % (self.gateway_id))
+        self._cc._post("/1/gateways/%s/event/factory_reset" % (self.gateway_id))
 
     def upgrade(self, software_version):
         """
@@ -259,7 +273,7 @@ class CogniacEdgeFlow(object):
         args = dict()
         if software_version is not None:
             args['software_version'] = software_version
-        self._cc._post("/gateways/%s/event/upgrade" % (self.gateway_id), json=args)
+        self._cc._post("/1/gateways/%s/event/upgrade" % (self.gateway_id), json=args)
 
     def set_boot_software_version(self, software_version):
         """
@@ -268,13 +282,13 @@ class CogniacEdgeFlow(object):
         args = dict()
         if software_version is not None:
             args['software_version'] = software_version
-        self._cc._post("/gateways/%s/event/set_boot_software_version" % (self.gateway_id), json=args)
+        self._cc._post("/1/gateways/%s/event/set_boot_software_version" % (self.gateway_id), json=args)
 
     def reboot(self):
         """
         Reboot the EdgeFlow
         """
-        self._cc._post("/gateways/%s/event/reboot" % (self.gateway_id))
+        self._cc._post("/1/gateways/%s/event/reboot" % (self.gateway_id))
 
     def ping(self, ping_id=None):
         """
@@ -284,7 +298,7 @@ class CogniacEdgeFlow(object):
         event = {"timestamp": time()}
         if ping_id is not None:
             event['ping_id'] = ping_id
-        self._cc._post("/gateways/%s/event/ping" % self.gateway_id, json=event)
+        self._cc._post("/1/gateways/%s/event/ping" % self.gateway_id, json=event)
 
     def trigger_camera_capture(self, subject_uid, trigger_domain_unit=None):
         """
@@ -294,7 +308,7 @@ class CogniacEdgeFlow(object):
         event = {'subject_uid': subject_uid}
         if trigger_domain_unit is not None:
             event['trigger_domain_unit'] = trigger_domain_unit
-        self._cc._post("/gateways/%s/event/trigger_camera_capture" % self.gateway_id, json=event)
+        self._cc._post("/1/gateways/%s/event/trigger_camera_capture" % self.gateway_id, json=event)
 
     def status(self, subsystem_name=None, start=None, end=None, reverse=True, limit=None):
         """
@@ -317,9 +331,9 @@ class CogniacEdgeFlow(object):
             args.append('limit=%d' % min(limit, 100))  # api support max limit of 100
 
         if subsystem_name:
-            url = "/gateways/%s/status/%s?" % (self.gateway_id, subsystem_name)
+            url = "/1/gateways/%s/status/%s?" % (self.gateway_id, subsystem_name)
         else:
-            url = "/gateways/%s/status?" % self.gateway_id
+            url = "/1/gateways/%s/status?" % self.gateway_id
 
         url += "&".join(args)
 
