@@ -22,7 +22,7 @@ def print_tenants(tenants):
 
 @register_line_magic
 def tenants(line):
-    tenants = cogniac.CogniacConnection.get_all_authorized_tenants(username, password)['tenants']
+    tenants = cogniac.CogniacConnection.get_all_authorized_tenants()['tenants']
     print_tenants(tenants)
 
 print "added ipython magic %tenants"
@@ -57,7 +57,7 @@ print "added ipython magic %authenticate"
 
 def print_detections(detections):
     # remove None values from dict
-    detections = [{k: v for k, v in d.iteritems() if v is not None} for d in detections]
+    detections = [{k: v for k, v in d.items() if v is not None} for d in detections]
 
     detections.sort(key=lambda x: x['created_at'])
 
@@ -83,7 +83,7 @@ print "added ipython magic %media_detections"
 
 def print_subjects(media_subjects):
     subjects = [ms['subject'] for ms in media_subjects]
-    subjects = [{k: v for k, v in s.iteritems() if v is not None} for s in subjects]
+    subjects = [{k: v for k, v in s.items() if v is not None} for s in subjects]
     subjects.sort(key=lambda x: x['updated_at'])
     for s in subjects:
         if 'timestamp' in s:
@@ -185,13 +185,24 @@ def usage(line):
     print tabulate(data, headers='firstrow')
 print "added ipython magic %usage"
 
-try:
-    username = os.environ['COG_USER']
-    password = os.environ['COG_PASS']
-    print "found environment credentials for %s" % username
-except:
-    print "No Cogniac Credentials. Specify username and password or set COG_USER and COG_PASS environment variables."
-    os._exit(1)
+
+
+@register_line_magic
+def login(tname):
+    """
+    attempt to match user supplied partial tenant name or tenant_id 
+    authenticate with the matched tenant
+    """
+    tenant_list = cogniac.CogniacConnection.get_all_authorized_tenants()['tenants']
+    def match(t):
+        return tname.lower() in t['name'].lower() or tname in t['tenant_id']
+    filter_tenant_list = filter(match, tenant_list)
+    if len(filter_tenant_list) == 1:
+        authenticate(filter_tenant_list[0]['tenant_id'])  # use tenant from command line
+    elif len(filter_tenant_list) > 1:
+        print_tenants(filter_tenant_list)  # show tenants that match
+    else:
+        print_tenants(tenant_list)  # show all tenants
 
 
 if 'COG_TENANT' in os.environ:
@@ -199,17 +210,4 @@ if 'COG_TENANT' in os.environ:
     print "found COG_TENANT %s" % tenant_id
     authenticate(tenant_id)
 else:
-    tenant_list = cogniac.CogniacConnection.get_all_authorized_tenants(username, password)['tenants']
-    if len(tenant_list) == 1:
-        authenticate(tenant_list[0]['tenant_id'])
-    else:
-        # see if user provided a partial tenant name or tenant_id on command line
-        def match(t):
-            return argv[-1].lower() in t['name'].lower() or argv[-1] in t['tenant_id']
-        filter_tenant_list = filter(match, tenant_list)
-        if len(filter_tenant_list) == 1:
-            authenticate(filter_tenant_list[0]['tenant_id'])  # use tenant from command line
-        elif len(filter_tenant_list) > 1:
-            print_tenants(filter_tenant_list)  # show tenants that match
-        else:
-            print_tenants(tenant_list)  # show all tenants
+    login(argv[-1])
