@@ -1,13 +1,14 @@
 """
 CogniacMedia Object Client
 
-Copyright (C) 2016 Cogniac Corporation
+Copyright (C) 2016-2022 Cogniac Corporation
 """
-
-from hashlib import md5
-from retrying import retry
 from .common import *
-from os import stat, path
+from hashlib import md5
+from os import stat, fstat, path, SEEK_END
+from retrying import retry
+from six.moves.urllib.parse import quote
+from time import time
 import platform
 
 platform_system = platform.system()
@@ -53,7 +54,7 @@ class CogniacMedia(object):
         connnection (CogniacConnection):     Authenticated CogniacConnection object
         media_id (String):                   The media_id of the Cogniac Media item to return
         """
-        resp = connection._get("/media/%s" % media_id)
+        resp = connection._get("/1/media/%s" % media_id)
 
         return CogniacMedia(connection, resp.json())
 
@@ -62,7 +63,7 @@ class CogniacMedia(object):
         """
         Search for a CogniacMedia item in current tenant by md5, filename, or external_media_id.
 
-        connnection (CogniacConnection):     Authenticated CogniacConnection object        
+        connnection (CogniacConnection):     Authenticated CogniacConnection object
         md5 (String):                        MD5 of media item
         filename (String):                   Original filename of media item
         external_media_id (String):          Customer specified unique ID
@@ -71,13 +72,13 @@ class CogniacMedia(object):
 
         returns list of CogniacMedia objects that match the query parameters
         """
-        
+
         if md5 is not None:
-            assert((filename is None) & (external_media_id is None) & (domain_unit is None))            
+            assert((filename is None) & (external_media_id is None) & (domain_unit is None))
             query = "md5=%s" % md5
         elif filename is not None:
-            assert((md5 is None) & (external_media_id is None) & (domain_unit is None))                        
-            query = "filename=%s" % filename
+            assert((md5 is None) & (external_media_id is None) & (domain_unit is None))
+            query = "filename=%s" % quote(filename)
         elif external_media_id is not None:
             assert((md5 is None) & (filename is None) & (domain_unit is None))
             query = "external_media_id=%s" % external_media_id
@@ -87,7 +88,7 @@ class CogniacMedia(object):
 
         def get_next(last_key=None):
             query_limit = limit if limit and limit < 100 else 100
-            url = "/media/all/search?%s&limit=%s" % (query, query_limit)
+            url = "/1/media/all/search?%s&limit=%s" % (query, query_limit)
             if last_key:
                 url += "&last_key=%s" % (last_key)
             resp = connection._get(url)
@@ -105,9 +106,9 @@ class CogniacMedia(object):
                     return matches
             if not last_key:
                 break
-        
+
         return matches
-    
+
     def __init__(self, connection, media_dict):
         """
         create a CogniacMedia
@@ -129,7 +130,7 @@ class CogniacMedia(object):
             raise AttributeError("%s is immutable" % name)
         if name in mutable_keys:
             data = {name: value}
-            resp = self._cc._post("/media/%s" % self.media_id, json=data)
+            resp = self._cc._post("/1/media/%s" % self.media_id, json=data)
             for k, v in resp.json().items():
                 super(CogniacMedia, self).__setattr__(k, v)
             return
@@ -178,7 +179,7 @@ class CogniacMedia(object):
         trigger_id (str):                 Unique trigger identifier leading to a media sequence containing this media
         sequence_ix (str):                The index of this media within a triggered sequence
         custom_data (str):                Opaque user-specified data associated with this media; limited to 32KB
-        fp (file):                        A '.read()'-supporting file-like object (under 16MB) from which to acquire
+        fp (file):                        A '.read()'-supporting file-like object from which to acquire
                                           the media instead of reading the media from the specified filename.
         """
 
@@ -216,14 +217,24 @@ class CogniacMedia(object):
 
         if filename.startswith('http'):
             args['source_url'] = filename
-        elif fp is None:  # local filename
-            fstat = stat(filename)
+        else:
             if 'media_timestamp' not in args:
-                # set the unspecified media timestamp to the earliest file time we have
-                args['media_timestamp'] = file_creation_time(filename)
-            if stat(filename).st_size > 12 * 1024 * 1024:
+                if fp is None:
+                    # set the unspecified media timestamp to the earliest file time we have
+                    args['media_timestamp'] = file_creation_time(filename)
+                else:
+                    args['media_timestamp'] = time()
+
+            if fp is None:
+                fsize = stat(filename).st_size
                 # use the multipart interface for large files
-                return CogniacMedia._create_multipart(connection, filename, args)
+            else:
+                fp.seek(0, SEEK_END) # most reliable way of finding file size.
+                fsize = fp.tell()
+                fp.seek(0)
+
+            if fsize > 12 * 1024 * 1024:
+                return CogniacMedia._create_multipart(connection, filename, fp, fsize, args)
 
         @retry(stop_max_attempt_number=8, wait_exponential_multiplier=500, retry_on_exception=server_error)
         def upload():
@@ -234,40 +245,40 @@ class CogniacMedia(object):
                 files = {filename: fp}
             else:
                 files = {filename: open(filename, 'rb')}
-            print(args)
-            print(files)
-            resp = connection._post("/media", data=args, files=files)
+            resp = connection._post("/1/media", data=args, files=files)
             return resp
 
         resp = upload()
         return CogniacMedia(connection, resp.json())
 
     @classmethod
-    def _create_multipart(cls, connection, filename, args):
+    def _create_multipart(cls, connection, filename, mfp, filesize, args):
         """
         upload via the multipart api
         """
-        def md5_hexdigest():
+        def md5_hexdigest(fp):
             """
             return the md5 hexdigest of a potentially very large file
             """
             md = md5()
-            fp = open(filename, 'rb')
             while True:
                 block = fp.read(8*1024*1024)
                 if not block:
                     return md.hexdigest()
                 md.update(block)
 
-        md5hash = md5_hexdigest()
+        if mfp is None:
+            mfp = open(filename, 'rb')
+        else:
+            mfp.seek(0)
+
+        md5hash = md5_hexdigest(mfp)
 
         @retry(stop_max_attempt_number=8, wait_exponential_multiplier=500, retry_on_exception=server_error)
         def post_data(data):
-            resp = connection._post("/media/resumable", json=data)
+            resp = connection._post("/1/media/resumable", json=data)
             return resp.json()
 
-        filesize = stat(filename).st_size
-
         data = {'upload_phase': 'start',
                 'file_size':    filesize,
                 'filename':     filename,
@@ -285,11 +296,11 @@ class CogniacMedia(object):
                     'video_file_chunk_no': chunk_no}
 
             files = {'file': chunk}
-            resp = connection._post("/media/resumable", data=data, files=files)
+            resp = connection._post("/1/media/resumable", data=data, files=files)
             return resp.json()
 
-        mfp = open(filename, 'rb')
         idx = 1
+        mfp.seek(0)
         while True:
             chunk = mfp.read(chunk_size)
             if not chunk:
@@ -308,7 +319,7 @@ class CogniacMedia(object):
         """
         delete the media object
         """
-        self._cc._delete("/media/%s" % self.media_id)
+        self._cc._delete("/1/media/%s" % self.media_id)
         self.__dict__.clear()
 
     @retry(stop_max_attempt_number=8, wait_exponential_multiplier=500, retry_on_exception=server_error)
@@ -365,7 +376,7 @@ class CogniacMedia(object):
         app_data          Optional extra app-specific data
         """
 
-        url = "/media/%s/detections" % (self.media_id)
+        url = "/1/media/%s/detections" % (self.media_id)
 
         if wait_capture_id is not None:
             url += "?wait_capture_id=%s" % wait_capture_id
@@ -394,14 +405,16 @@ class CogniacMedia(object):
         timestamp		time of last update
         app_data_type	optional app data type if applicable
         app_data        optional app data if applicable
-        consensus		'True', 'False', or None
+        consensus		'True', 'False', 'Sidelined', or None
                         'True' if there is consensus that the subject is associated with the media
                             (Media will be used as a positive training example of the subject)
                         'False' if there is consensus that the subject is not associated w/the media
                             (Media will be used as a negative training example of the subject.)
                          None if if there is not enough evidence to reach consensus
+                         'Sidelined' if there is consensus that the media should not be used 
+                            for training applications dependent on the subject.
                          Some application types only support 'True' or None.
                          }
         """
-        resp = self._cc._get("/media/%s/subjects" % (self.media_id))
+        resp = self._cc._get("/1/media/%s/subjects" % (self.media_id))
         return resp.json()['data']
