@@ -70,7 +70,7 @@ class CogniacSubject(object):
         if external_id:
             data['external_id'] = external_id
 
-        resp = connection._post("/subjects", json=data)
+        resp = connection._post("/1/subjects", json=data)
 
         return CogniacSubject(connection, resp.json())
 
@@ -88,7 +88,7 @@ class CogniacSubject(object):
         connnection (CogniacConnection):     Authenticated CogniacConnection object
         subject_id (String):                 The subject_id of the Cogniac Subject to return
         """
-        resp = connection._get("/subjects/%s" % subject_uid)
+        resp = connection._get("/1/subjects/%s" % subject_uid)
         return CogniacSubject(connection, resp.json())
 
     ##
@@ -110,7 +110,7 @@ class CogniacSubject(object):
         if public_write:
             args.append("public_read_write=True")
 
-        url = "/tenants/%s/subjects?" % connection.tenant.tenant_id
+        url = "/1/tenants/%s/subjects?" % connection.tenant.tenant_id
         url += "&".join(args)
 
         resp = connection._get(url)
@@ -164,7 +164,7 @@ class CogniacSubject(object):
         elif name:
             args.append('name=%s' % name)
 
-        url = "/tenants/%s/subjects?" % connection.tenant.tenant_id
+        url = "/1/tenants/%s/subjects?" % connection.tenant.tenant_id
         url += "&".join(args)
 
         resp = connection._get(url)
@@ -195,7 +195,7 @@ class CogniacSubject(object):
         """
         Delete the subject.
         """
-        resp = self._cc._delete("/subjects/%s" % self.subject_uid)
+        resp = self._cc._delete("/1/subjects/%s" % self.subject_uid)
 
         for k in self._sub_keys:
             delattr(self, k)
@@ -207,7 +207,7 @@ class CogniacSubject(object):
             raise AttributeError("%s is immutable" % name)
         if name in ['name', 'description', 'expires_in', 'external_id', 'custom_data']:
             data = {name: value}
-            resp = self._cc._post("/subjects/%s" % self.subject_uid, json=data)
+            resp = self._cc._post("/1/subjects/%s" % self.subject_uid, json=data)
             for k, v in resp.json().items():
                 super(CogniacSubject, self).__setattr__(k, v)
             return
@@ -321,7 +321,7 @@ class CogniacSubject(object):
             else:
                 files = {'file': open(filename, 'rb')}
                 # api.add_resource(SubjectReferenceMedia, '/1/subjects/<string:subject_uid>/referenceMedia')
-            resp = self._cc._post("/subjects/{}/referenceMedia".format(self.subject_uid), data=args, files=files)
+            resp = self._cc._post("/1/subjects/{}/referenceMedia".format(self.subject_uid), data=args, files=files)
             return resp
 
         resp = upload()
@@ -350,7 +350,7 @@ class CogniacSubject(object):
 
         if focus is not None:
             data['focus'] = focus
-        self._cc._delete("/subjects/%s/media" % self.subject_uid, json=data)
+        self._cc._delete("/1/subjects/%s/media" % self.subject_uid, json=data)
 
     ##
     #  associate_media
@@ -375,6 +375,7 @@ class CogniacSubject(object):
                                          'box'     Optional dictionary of bounding box pixel offsets (with keys x0, x1, y0, y1) within the frame.
         consensus (str)                  'True' if media is associated with subject,
                                          'False' if media is NOT associated with subject.
+                                         'Sidelined' if consensus was decisively not provided.
                                          'None' if consenus is unknown.  Required uncal_prob
         probability (float)              association probability, only valid if consensus = 'None'
         force_feedback (bool)            True to force feedback on the media item in downstream apps
@@ -398,10 +399,10 @@ class CogniacSubject(object):
         if focus is not None:
             data['focus'] = focus
 
-        assert(consensus in ['True', 'False', 'None'])
+        assert(consensus in ['True', 'False', 'None', 'Sidelined'])
         data['consensus'] = consensus
 
-        if consensus is 'None' and probability is None:
+        if consensus == 'None' and probability is None:
             data['uncal_prob'] = .99
 
         if probability is not None:
@@ -416,7 +417,7 @@ class CogniacSubject(object):
         data['app_data_type'] = app_data_type
         data['app_data'] = app_data
 
-        resp = self._cc._post("/subjects/%s/media" % self.subject_uid, json=data)
+        resp = self._cc._post("/1/subjects/%s/media" % self.subject_uid, json=data)
         return resp.json()['capture_id']
 
     ##
@@ -431,7 +432,7 @@ class CogniacSubject(object):
         reverse (bool)         reverse the sorting order: sort high to low
         probability_lower:     filter by probability > probability_lower
         probability_upper:     filter by probability < probability_upper
-        consensus (string):    filter by consensus label: "True", "False"
+        consensus (string):    filter by consensus label: "True", "False" or "None"
         sort_probability(bool) Sort by probability instead of last update timestamp
         limit (int)            yield maximum of limit results
         abridged_media (bool)  return full media items if False (slower), otherwise return just media_id's for each media_item
@@ -450,11 +451,12 @@ class CogniacSubject(object):
         timestamp	time of last update to subject media association
         app_data_type	optional app data type if applicable
         app_data        optional app data if applicable
-        consensus		'True', 'False', or , or None
+        consensus		'True', 'False', or 'Sidelined', or None
                         'True' if there is consensus that the subject is associated with the media
                             (Media will be used as a positive training example of the subject)
                         'False' if there is consensus that the subject is not associated w/the media
                             (Media will be used as a negative training example of the subject.)
+                        'Sidelined' if the media's association with the subject was decisively not provided. 
                          None if if there is not enough evidence to reach consensus
                          Some application types only support 'True' or None.
         """
@@ -469,7 +471,7 @@ class CogniacSubject(object):
         if probability_upper is not None:
             args.append("probability_upper=%f" % probability_upper)
         if consensus is not None:
-            assert(consensus in ['True', 'False'])
+            assert(consensus in ['True', 'False', 'Sidelined', 'None'])
             args.append("consensus=%s" % consensus)
         if reverse:
             args.append('reverse=True')
@@ -483,7 +485,7 @@ class CogniacSubject(object):
         if abridged_media:
             args.append('abridged_media=True')
 
-        url = "/subjects/%s/media?" % self.subject_uid
+        url = "/1/subjects/%s/media?" % self.subject_uid
         url += "&".join(args)
 
         @retry(stop_max_attempt_number=8, wait_exponential_multiplier=500, retry_on_exception=server_error)
